CamelConfig

Struct CamelConfig 

pub struct CamelConfig {
    pub routes: Vec<String>,
    pub watch: bool,
    pub runtime_journal_path: Option<String>,
    pub log_level: String,
    pub timeout_ms: u64,
    pub components: ComponentsConfig,
    pub observability: ObservabilityConfig,
    pub supervision: Option<SupervisionCamelConfig>,
}

Fields

routes: Vec<String>watch: bool

Enable file-watcher hot-reload. Defaults to false. Can be overridden per profile in Camel.toml or via --watch / --no-watch CLI flags.

runtime_journal_path: Option<String>

Optional stable runtime journal path for CQRS event durability/replay.

When unset, runtime durability/replay is disabled and runtime state is ephemeral.

log_level: Stringtimeout_ms: u64components: ComponentsConfigobservability: ObservabilityConfigsupervision: Option<SupervisionCamelConfig>

Implementations

Source

impl CamelConfig

pub fn from_file(path: &str) -> Result<Self, ConfigError>

pub fn from_file_with_env(path: &str) -> Result<Self, ConfigError>

pub fn from_file_with_profile( path: &str, profile: Option<&str>, ) -> Result<Self, ConfigError>

pub fn from_file_with_profile_and_env( path: &str, profile: Option<&str>, ) -> Result<Self, ConfigError>

pub fn from_env_or_default() -> Result<Self, ConfigError>

Source

impl CamelConfig

pub fn load_routes(path: &str) -> Result<Vec<RouteDefinition>, CamelError>

Load routes from config file and return them (without adding to context yet) This allows components to be registered before routes are resolved

pub fn configure_context( config: &CamelConfig, ) -> Result<CamelContext, CamelError>

Create a CamelContext configured from this CamelConfig.

Always installs a unified tracing subscriber (Layers 1–3, plus Layer 4 when OTel is enabled). OtelService, if present, only manages providers — it never installs a subscriber.